#
# spec file for package spirv-tools
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_unconverted 2020.1
%define lname libSPIRV-Tools-suse17

Name:           spirv-tools
Version:        2020.2
Release:        lp151.4.3.1
Summary:        API and commands for processing SPIR-V modules
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/KhronosGroup/SPIRV-Tools

Source:         https://github.com/KhronosGroup/SPIRV-Tools/archive/v%version.tar.gz
Source9:        baselibs.conf
Patch1:         ver.diff
Patch2:         gcc48.diff
BuildRequires:  bison
BuildRequires:  cmake >= 2.8.12
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  python3-xml
BuildRequires:  spirv-headers >= 1.5.1.corrected+git24

%description
The package includes an assembler, binary module parser,
disassembler, and validator for SPIR-V.

%package -n %lname
Summary:        SPIR-V tool component library
Group:          System/Libraries

%description -n %lname
The SPIR-V Tool library contains all of the implementation details
driving the SPIR-V assembler, binary module parser, disassembler and
validator, and is used in the standalone tools whilst also enabling
integration into other code bases directly.

%package devel
Summary:        Development headers for the SPIR-V tool library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
The SPIR-V Tool library contains all of the implementation details
driving the SPIR-V assembler, binary module parser, disassembler and
validator, and is used in the standalone tools whilst also enabling
integration into other code bases directly.

%prep
%setup -qn SPIRV-Tools-%version
%autopatch -p1

%build
%cmake -D"SPIRV-Headers_SOURCE_DIR=%_prefix"
make %{?_smp_mflags}

%install
%cmake_install

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%_bindir/spirv-*
%doc LICENSE

%files -n %lname
%_libdir/libSPIRV-Tools.so.*
%_libdir/libSPIRV-Tools-link.so.*
%_libdir/libSPIRV-Tools-opt.so.*
%_libdir/libSPIRV-Tools-reduce.so.*
%_libdir/libSPIRV-Tools-shared.so.*

%files devel
%_libdir/cmake/
%_libdir/libSPIRV-Tools.so
%_libdir/libSPIRV-Tools-link.so
%_libdir/libSPIRV-Tools-opt.so
%_libdir/libSPIRV-Tools-reduce.so
%_libdir/libSPIRV-Tools-shared.so
%_libdir/pkgconfig/SPIRV-Tools.pc
%_libdir/pkgconfig/SPIRV-Tools-shared.pc
%_includedir/spirv-tools/

%changelog
* Wed Apr  8 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.2
  * Support extended instructions in the vscode language server.
  * Make spvOpcodeString part of the public API.
  * Add support for KHR_ray_{query,tracing} extensions.
  * Add validation support for SPV_AMD_shader_image_load_store_lod.
* Thu Feb 20 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2020.1
  * Add spvParseVulkanEnv
  * Handle TimeAMD in AmdExtensionToKhrPass
* Sun Jan 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 2020.1~git24 (323a81fc)
  * Added basic Vulkan 1.2 support and validation of 1.2.
  * spirv-fuzz: added fuzzer pass to perform module donation.
  * Supports OpenCL.DebugInfo.100 extended instruction set.
  * Added support for SPV_KHR_non_semantic_info.
  * spirv-fuzz: Transformations to add types, constants and
    variables, and to add a new function to a module.
  * Made instrumentation format version 2 the default.
* Thu Dec 12 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 2019.5
  * Re-enable OpReadClockKHR validation
  * spirv-fuzz: simplify transformation for replacing an id with
    a synonym
  * spirv-fuzz: Eliminate spurious semicolons
  * Update Offset to ConstOffset bitmask if operand is constant
  * Validate array stride does not cause overlap
  * Fix operand access of composite in upgrade memory model
  * Kill the id-to-func map after wrap-opkill
  * Handle OpPhi with no in operands in value numbering
  * Handle unreachable block when computing register pressure
  * spirv-fuzz: Improve debugging facilities
  * Validate nested constructs
  * spirv-fuzz: Use validator to check break/continue dominance
    conditions
  * spirv-fuzz: function outlining fuzzer pass
* Thu Nov  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 2019.5~git157
  * Extend reducer to remove relaxed precision decorations
  * SPIRV-Tools support for SPIR-V 1.5
  * Add SPV_KHR_shader_clock validation
  * Add fuzzer for spirv-dis call path
* Wed Aug 21 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 2019.5~git11
  * Add builtin validation for SPV_NV_shader_sm_builtins
  * Add transformation to replace a boolean constant with a
    numeric comparison
  * Add validation for Subgroup builtins
  * Add replayer tool for spirv-fuzz
  * Validate Volatile memory semantics bit
  * Add validation for SPV_EXT_demote_to_helper_invocation
  * Add 'copy object' transformation
  * Add SPV_EXT_physical_storage_buffer to opt whitelists
  * Add descriptor array scalar replacement
* Tue Jun  4 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 2019.4~git33
  * Support SPIR-V 1.4
  * Add library for spirv-fuzz
  * Add spirv-fuzz tool.
  * Add "split block" transformation.
  * Add validation for SPV_EXT_fragment_shader_interlock
* Sun Mar 17 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new snapshot 2019.2.git25 (2ac348b5) to be in line
  with current spirv-headers.
  * Add --strip-atomic-counter-memory
  * Add validation of storage classes for WebGPU
  * Add validation for ExecutionMode in WebGPU
  * Implement WebGPU specific CFG validation
  * Allow NonWritable to target struct members
  * Add validation for SPV_NV_cooperative_matrix
* Wed Feb 20 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.2
  * General:
  * Support SPV_EXT_physical_storage_buffer
  * Optimizer:
  * Upgrade memory model improvments for modf and frexp.
  * Add a new pass to move loads closer to their uses: code sinking.
  * Invalidating the type manager now invalidates the constant
    manager.
  * Expand instrumentation pass for bindless bounds checking to
    runtime-sized descriptor arrays.
  * Add a new dead struct member elimination pass
  * Validator:
  * Support SPV_KHR_no_integer_wrap and related decorations.
  * Validate Vulkan rules for OpTypeRuntimeArray.
  * Validate NonWritable decoration.
  * Many WebGPU specific validation rules were added.
  * Validate variable pointer related function call rules.
* Mon Jan  7 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2019.1
  * Created a new tool called spirv-reduce.
  * New optimization pass to update the memory model from GLSL450
    to VulkanKHR.
  * Recognize OpTypeAccelerationStructureNV as a type instruction
    and ray tracing storage classes.
  * Add --target-env flag to spirv-opt.
  * Add --webgpu-mode flag to run optimizations for webgpu.
  * Outupt disassembled line number instead of byte offset in
    validation errors.
* Sat Nov 10 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2018.6
  * Added support for the Nvidia Turing and ray tracing extensions.
* Fri Aug 24 2018 jengelh@inai.de
- Update to new upstream release 2018.4
  * Added missing SPV extension strings.
  * Taught DecorationManager about OpDecorateStringGOOGLE.
  * Added recent Google extensions to optimizer whitelists.
  * Added a loop peeling utility.
  * Added Vulkan validation rules for BuiltIn variables and
    Vulkan specific atomic result type restriction.
  * New spirv-1.3 rules for control barrier.
  * Added OpPhi validation rules.
  * Use standard SPIR-V version scheme for version requirement.
  * ZIV and SIV loop dependence analysis.
  * Added a loop peeling pass, register liveness analysis,
    a loop fusion pass, and the --strip-reflect pass.
  * Support for SPV_KHR_8bit_storage.
* Wed Mar 28 2018 meissner@suse.com
- add spirv-tools-devel for baselibs, for wine usage.
* Thu Mar  8 2018 jengelh@inai.de
- Update to new upstream release 2018.2
  * SubgroupBallotKHR can enable SubgroupSize & SubgroupLocalInvocationId
  * Support SPIR-V 1.3 and Vulkan 1.1
* Wed Feb  7 2018 jengelh@inai.de
- Update to new upstream release 2018.0
  * Added OpenCL ExtInst validation rules
  * Add adjacency validation pass
  * Add memory semantics checks to validate atomics
  * Allow relaxing validation of pointers in logical
    addressing mode
* Thu Jan  4 2018 tchvatal@suse.com
- Make sure to build just with python3
- Remove needles buildroot variable and default defattrs
- Use autopatch to apply patches
* Fri Nov 17 2017 jengelh@inai.de
- Update to new snapshot 2017.0.g103
  * Update MARK-V to version 1.01
  * Add new checks to validate arithmetics pass
  * Recognize SPV_AMD_shader_fragment_mask
  * Add validate logicals pass to the validator
  * Detach MARK-V from the validator
* Tue Jul 18 2017 jengelh@inai.de
- Update to new snapshot 2016.7~g145
  * Validation of type decls for SPV_KHR_16bit_storage
  * Allow using FPRoundingMode when see VK_KHR_16bit_storage
  * Validator parses and registers OpExtension
  * Validator checks if operands require extension
  * Validator dissallows unsupported Vulkan capability
  * Update capability tests for SPV_KHR_16bit_storage rev 7
  * Support SPV_AMD_gcn_shader
  * Add FlattenDecoration transform
  * Validator support for Variable Pointer extension.
  * Support SPV_KHR_storage_buffer_storage_class
  * Add SPIR-V 1.2 support, for OpenCL 2.2
  * Added extension SPV_VALIDATOR_ignore_type_decl_unique
  * Add support for SPV AMD extensions
  * MARK-V decoder supports extended instructions
  * DeadBranchElim: Improve algorithm to only remove blocks with
    no predecessors
  * Opt: Add new size-reduction passes to usage message.
  * Add multi-sequence move-to-front implementation.
  * Add MemPass, move all shared functions to it.
  * Add CommonUniformElim pass.
  * Mem2Reg: Allow Image and Sampler types as base target types.
* Mon Feb 20 2017 jengelh@inai.de
- Update to new snapshot 2016.7~g28
  * The Signedness in OpTypeInt must always be 0.
- Add baselibs.conf [needed by libvulkan1, needed by libgtk4-0]
* Thu Feb  2 2017 jengelh@inai.de
- Update to new snapshot 2016.7~g24
  * Add classes for representing SPIR-V language constructs in memory.
  * Add an option to spvBinaryToText() to ignore header output.
  * Add IrBuilder for constructing SPIR-V in-memory representation.
  * Add Pass, PassManager, and StripDebugInfoPass.
  * Add the spirv-opt command line tool.
  * Fixes segfault for loops without back-edges
  * Allow missing memory model instructions in modules.
  * Add spirv-lesspipe.sh
  * Add spirv-dis/spirv-as support for emacs when loading .spv binaries
- Add gcc48.diff
* Mon Jun 13 2016 jengelh@inai.de
- Initial package (version 1.1) for build.opensuse.org
- Add ver.diff
